@@ -58,7 +58,7 @@ G_DEFINE_TYPE_WITH_CODE (GoaFacebookProvider, goa_facebook_provider, GOA_TYPE_OA
                          goa_provider_ensure_extension_points_registered ();
                          g_io_extension_point_implement (GOA_PROVIDER_EXTENSION_POINT_NAME,
 							 g_define_type_id,
-							 "facebook",
+							 GOA_FACEBOOK_NAME,
 							 0));
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -66,7 +66,7 @@ G_DEFINE_TYPE_WITH_CODE (GoaFacebookProvider, goa_facebook_provider, GOA_TYPE_OA
 static const gchar *
 get_provider_type (GoaProvider *_provider)
 {
-  return "facebook";
+  return GOA_FACEBOOK_NAME;
 }
 
 static gchar *
@@ -270,14 +270,11 @@ get_identity_sync (GoaOAuth2Provider  *provider,
 
  out:
   g_clear_error (&identity_error);
+  g_clear_object (&call);
+  g_clear_object (&parser);
+  g_clear_object (&proxy);
   g_free (id);
   g_free (presentation_identity);
-  if (parser != NULL)
-    g_object_unref (parser);
-  if (call != NULL)
-    g_object_unref (call);
-  if (proxy != NULL)
-    g_object_unref (proxy);
   return ret;
 }
 
@@ -435,10 +432,8 @@ build_object (GoaProvider         *provider,
   ret = TRUE;
 
  out:
-  if (chat != NULL)
-    g_object_unref (chat);
-  if (account != NULL)
-    g_object_unref (account);
+  g_clear_object (&chat);
+  g_clear_object (&account);
   g_clear_object (&photos);
   g_clear_object (&maps);
   return ret;
